# check whether the user wants to overload compile flags upon calling make
#
# Provides the following macros:
#
#   initialize_compiler_script() : needs to be called before further flags are added to CMAKE_CXX_FLAGS
#   finalize_compiler_script()   : needs to be called at the end of the cmake macros, e.g. in finalize_dune_project
#
#   By default this feature is disabled. Use -DALLOW_CXXFLAGS_OVERWRITE=ON to activate.
#   Then the following is possible:
#
#   make CXXFLAGS="your flags" GRIDTYPE="grid type"
#
#   GRIDTYPE can be anything defined in config.h via the dune_define_gridtype macro from dune-grid.
#   Furthermore any CPP variable of the form -DVAR=VALUE can be overloaded on the command line.
#
#   Note: If you don't know what this is or what it's good for, don't use it.
#
option(GRID_SELECTOR OFF)

set(GRID_SELECTOR_FILE "")
# init compiler script and store CXX flags
macro(initialize_grid_selector)
  if(GRID_SELECTOR)
    set(GRID_SELECTOR_FILE ${CMAKE_BINARY_DIR}/gridselector.hh)
    file(write ${GRID_SELECTOR_FILE} "// Autogenerated Grid selectors")
  endif()
endmacro()

# init compiler script and store CXX flags
macro(finalize_grid_selector output)
  if(GRID_SELECTOR)
    file(append ${GRID_SELECTOR_FILE} ${output})
  endif()
endmacro()

